warn_if_not_latest_build

Function warn_if_not_latest_build 

pub fn warn_if_not_latest_build(manifest_path: &Path, profile: Option<&str>)
Prints a warning to stderr if the given profile is not the same as the most recent build in the given application directory.